@@ -37,7 +37,7 @@ RESOURCES_MAPPING_FILE: str = os.path.join(SCHEMA_DIR, "__resources-mappings.jso
 
 
 def _is_kind_and_namespaced(client: str, _key: str, _data: Dict[str, Any]) -> Dict[str, Any]:
-    x_kubernetes_group_version_kind = _data["x-kubernetes-group-version-kind"][0]
+    x_kubernetes_group_version_kind = extract_group_kind_version(_kind_schema=_data)
     _kind = x_kubernetes_group_version_kind["kind"]
     _group = x_kubernetes_group_version_kind.get("group")
     _version = x_kubernetes_group_version_kind.get("version")
@@ -366,34 +366,39 @@ def generate_resource_file_from_dict(
 
 
 def types_generator(key_dict: Dict[str, Any]) -> Dict[str, str]:
-    type_for_docstring: str = "Dict[str, Any]"
+    type_for_docstring: str = "Any"
     type_from_dict_for_init: str = ""
+    # A resource field may be defined with `x-kubernetes-preserve-unknown-fields`. In this case, `type` is not provided.
+    resource_type = key_dict.get("type")
 
     # All fields must be set with Optional since resource can have yaml_file to cover all args.
-    if key_dict["type"] == "array":
+    if resource_type == "array":
         type_for_docstring = "List[Any]"
 
-    elif key_dict["type"] == "string":
+    elif resource_type == "string":
         type_for_docstring = "str"
         type_from_dict_for_init = f'Optional[{type_for_docstring}] = ""'
 
-    elif key_dict["type"] == "boolean":
+    elif resource_type == "boolean":
         type_for_docstring = "bool"
 
-    elif key_dict["type"] == "integer":
+    elif resource_type == "integer":
         type_for_docstring = "int"
 
+    elif resource_type == "object":
+        type_for_docstring = "Dict[str, Any]"
+
     if not type_from_dict_for_init:
         type_from_dict_for_init = f"Optional[{type_for_docstring}] = None"
 
     return {"type-for-init": type_from_dict_for_init, "type-for-doc": type_for_docstring}
 
 
-def get_property_schema(property: Dict[str, Any]) -> Dict[str, Any]:
-    if _ref := property.get("$ref"):
+def get_property_schema(property_: Dict[str, Any]) -> Dict[str, Any]:
+    if _ref := property_.get("$ref"):
         with open(f"{SCHEMA_DIR}/{_ref.rsplit('.')[-1].lower()}.json") as fd:
             return json.load(fd)
-    return property
+    return property_
 
 
 def format_description(description: str) -> str:
@@ -419,14 +424,16 @@ def prepare_property_dict(
         if key in keys_to_ignore:
             continue
 
-        val_schema = get_property_schema(property=val)
+        val_schema = get_property_schema(property_=val)
         type_dict = types_generator(key_dict=val_schema)
         python_name = convert_camel_case_to_snake_case(string_=key)
         resource_dict[dict_key].append({
             "name-for-class-arg": python_name,
             "property-name": key,
             "required": key in required,
-            "description": format_description(description=val_schema["description"]),
+            "description": format_description(
+                description=val_schema.get("description", "No field description from API; please add description")
+            ),
             "type-for-docstring": type_dict["type-for-doc"],
             "type-for-class-arg": f"{python_name}: {type_dict['type-for-init']}",
         })
@@ -452,10 +459,11 @@ def parse_explain(
 
         schema_properties: Dict[str, Any] = _kind_schema["properties"]
         fields_required = _kind_schema.get("required", [])
-        resource_dict.update(_kind_schema["x-kubernetes-group-version-kind"][0])
+
+        resource_dict.update(extract_group_kind_version(_kind_schema=_kind_schema))
 
         if spec_schema := schema_properties.get("spec", {}):
-            spec_schema = get_property_schema(property=spec_schema)
+            spec_schema = get_property_schema(property_=spec_schema)
             spec_required = spec_schema.get("required", [])
             resource_dict = prepare_property_dict(
                 schema=spec_schema.get("properties", {}),
@@ -508,6 +516,17 @@ def parse_explain(
     return _resources
 
 
+def extract_group_kind_version(_kind_schema: Dict[str, Any]) -> Dict[str, str]:
+    group_kind_versions: List[Dict[str, str]] = _kind_schema["x-kubernetes-group-version-kind"]
+    group_kind_version = group_kind_versions[0]
+
+    for group_kind_version in group_kind_versions:
+        if group_kind_version.get("group"):
+            break
+
+    return group_kind_version
+
+
 def class_generator(
     kind: str,
     overwrite: bool = False,
